% Display the linear model of the simulation example, the linear observer,
% and the state-feedback controller.
%
% --
% Supplementary material to:
% Sebastian Trimpe, "Stability Analysis of Distributed Event-Based State
% Estimation", IEEE Conference on Decision and Control (CDC), 2014.
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%

% Revision history
% [21.03.14]   preliminary version, published with initial submission
% [14.09.14]   update for final submission

clear;

%% Perform the controller and observer designs, and load the model
DesignControllerAndObserver;


%% Display model, controller, and observer gain
% Model
disp('Simulation model of pendulum with two arms.');
disp(' ');
disp('Discrete-time state-space model used for CONTROLLER design.');
disp('  x(k) = A x(k-1) + B u(k-1)  ');
disp('with...');
disp('A=');
disp(linMod_sim.A);

disp('B=');
disp(linMod_sim.B);

% disp('C=');
% disp(C);

disp(' ');
disp('State-feedback controller gain...');
disp('F=');
disp(F);
disp('Magnitude of eigenvalues of A+BF:');
disp(abs(eig(linMod_sim.A+linMod_sim.B*F)));
disp(' ');
disp(' ');


disp('Discrete-time state-space model used for ESTIMATOR design.');
disp(' ');
disp('Arm velocities are removed from state-space and introduced as secondary');
disp('input for the purpose of state estimation.  This can be done, since the');
disp('model structure above is such that x_2(k) = u_1(k-1) and x_4(k) = u_2(k-1).');
disp(' ');
disp('  x(k) = A x(k-1) + B1 u(k-1) + B2 u(k-2)  ');
disp('  y(k) = C x(k)  ');
disp('with...');
disp('A=');
disp(linMod_est.A);

disp('B1=');
disp(linMod_est.B);

disp('B2=');
disp(linMod_est.Bprev);

disp('C=');
disp(linMod_est.C);

disp(' ');
disp('Linear observer gain...');
disp('L=');
disp(L);

disp('Magnitude of eigenvalues of (I-LC)A:');
disp(abs(eig((eye(4)-L*linMod_est.C)*linMod_est.A)));